==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/guestconfiguration/kotlin/GuestConfigurationAssignmentsVMSSArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.guestconfiguration.kotlin

import com.pulumi.azurenative.guestconfiguration.GuestConfigurationAssignmentsVMSSArgs.builder
import com.pulumi.azurenative.guestconfiguration.kotlin.inputs.GuestConfigurationAssignmentPropertiesArgs
import com.pulumi.azurenative.guestconfiguration.kotlin.inputs.GuestConfigurationAssignmentPropertiesArgsBuilder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Guest configuration assignment is an association between a machine and guest configuration.
 * Azure REST API version: 2022-01-25.
 * ## Example Usage
 * ### Create or update guest configuration assignment
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var guestConfigurationAssignmentsVMSS = new AzureNative.GuestConfiguration.GuestConfigurationAssignmentsVMSS("guestConfigurationAssignmentsVMSS", new()
 *     {
 *         Location = "westcentralus",
 *         Name = "NotInstalledApplicationForWindows",
 *         Properties = new AzureNative.GuestConfiguration.Inputs.GuestConfigurationAssignmentPropertiesArgs
 *         {
 *             Context = "Azure policy",
 *             GuestConfiguration = new AzureNative.GuestConfiguration.Inputs.GuestConfigurationNavigationArgs
 *             {
 *                 AssignmentType = "ApplyAndAutoCorrect",
 *                 ConfigurationParameter = new[]
 *                 {
 *                     new AzureNative.GuestConfiguration.Inputs.ConfigurationParameterArgs
 *                     {
 *                         Name = "[InstalledApplication]NotInstalledApplicationResource1;Name",
 *                         Value = "NotePad,sql",
 *                     },
 *                 },
 *                 ContentHash = "123contenthash",
 *                 ContentUri = "https://thisisfake/pacakge",
 *                 Name = "NotInstalledApplicationForWindows",
 *                 Version = "1.0.0.3",
 *             },
 *         },
 *         ResourceGroupName = "myResourceGroupName",
 *         VmssName = "myVMSSName",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/guestconfiguration/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * pulumi.Run(func(ctx *pulumi.Context) error {
 * _, err := guestconfiguration.NewGuestConfigurationAssignmentsVMSS(ctx, "guestConfigurationAssignmentsVMSS", &guestconfiguration.GuestConfigurationAssignmentsVMSSArgs{
 * Location: pulumi.String("westcentralus"),
 * Name: pulumi.String("NotInstalledApplicationForWindows"),
 * Properties: guestconfiguration.GuestConfigurationAssignmentPropertiesResponse{
 * Context: pulumi.String("Azure policy"),
 * GuestConfiguration: interface{}{
 * AssignmentType: pulumi.String("ApplyAndAutoCorrect"),
 * ConfigurationParameter: guestconfiguration.ConfigurationParameterArray{
 * &guestconfiguration.ConfigurationParameterArgs{
 * Name: pulumi.String("[InstalledApplication]NotInstalledApplicationResource1;Name"),
 * Value: pulumi.String("NotePad,sql"),
 * },
 * },
 * ContentHash: pulumi.String("123contenthash"),
 * ContentUri: pulumi.String("https://thisisfake/pacakge"),
 * Name: pulumi.String("NotInstalledApplicationForWindows"),
 * Version: pulumi.String("1.0.0.3"),
 * },
 * },
 * ResourceGroupName: pulumi.String("myResourceGroupName"),
 * VmssName: pulumi.String("myVMSSName"),
 * })
 * if err != nil {
 * return err
 * }
 * return nil
 * })
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.guestconfiguration.GuestConfigurationAssignmentsVMSS;
 * import com.pulumi.azurenative.guestconfiguration.GuestConfigurationAssignmentsVMSSArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var guestConfigurationAssignmentsVMSS = new GuestConfigurationAssignmentsVMSS("guestConfigurationAssignmentsVMSS", GuestConfigurationAssignmentsVMSSArgs.builder()
 *             .location("westcentralus")
 *             .name("NotInstalledApplicationForWindows")
 *             .properties(Map.ofEntries(
 *                 Map.entry("context", "Azure policy"),
 *                 Map.entry("guestConfiguration", Map.ofEntries(
 *                     Map.entry("assignmentType", "ApplyAndAutoCorrect"),
 *                     Map.entry("configurationParameter", Map.ofEntries(
 *                         Map.entry("name", "[InstalledApplication]NotInstalledApplicationResource1;Name"),
 *                         Map.entry("value", "NotePad,sql")
 *                     )),
 *                     Map.entry("contentHash", "123contenthash"),
 *                     Map.entry("contentUri", "https://thisisfake/pacakge"),
 *                     Map.entry("name", "NotInstalledApplicationForWindows"),
 *                     Map.entry("version", "1.0.0.3")
 *                 ))
 *             ))
 *             .resourceGroupName("myResourceGroupName")
 *             .vmssName("myVMSSName")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:guestconfiguration:GuestConfigurationAssignmentsVMSS NotInstalledApplicationForWindows /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Compute/virtualMachineScaleSets/{vmssName}/providers/Microsoft.GuestConfiguration/guestConfigurationAssignments/{name}
 * ```
 * @property location Region where the VM is located.
 * @property name Name of the guest configuration assignment.
 * @property properties Properties of the Guest configuration assignment.
 * @property resourceGroupName The resource group name.
 * @property vmssName The name of the virtual machine scale set.
 */
public data class GuestConfigurationAssignmentsVMSSArgs(
    public val location: Output<String>? = null,
    public val name: Output<String>? = null,
    public val properties: Output<GuestConfigurationAssignmentPropertiesArgs>? = null,
    public val resourceGroupName: Output<String>? = null,
    public val vmssName: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.guestconfiguration.GuestConfigurationAssignmentsVMSSArgs> {
    override fun toJava():
        com.pulumi.azurenative.guestconfiguration.GuestConfigurationAssignmentsVMSSArgs =
        com.pulumi.azurenative.guestconfiguration.GuestConfigurationAssignmentsVMSSArgs.builder()
            .location(location?.applyValue({ args0 -> args0 }))
            .name(name?.applyValue({ args0 -> args0 }))
            .properties(properties?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .resourceGroupName(resourceGroupName?.applyValue({ args0 -> args0 }))
            .vmssName(vmssName?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [GuestConfigurationAssignmentsVMSSArgs].
 */
@PulumiTagMarker
public class GuestConfigurationAssignmentsVMSSArgsBuilder internal constructor() {
    private var location: Output<String>? = null

    private var name: Output<String>? = null

    private var properties: Output<GuestConfigurationAssignmentPropertiesArgs>? = null

    private var resourceGroupName: Output<String>? = null

    private var vmssName: Output<String>? = null

    /**
     * @param value Region where the VM is located.
     */
    @JvmName("aniopgriwkuhktvs")
    public suspend fun location(`value`: Output<String>) {
        this.location = value
    }

    /**
     * @param value Name of the guest configuration assignment.
     */
    @JvmName("diqsvampqchjkcpt")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value Properties of the Guest configuration assignment.
     */
    @JvmName("lftalixjuapefved")
    public suspend fun properties(`value`: Output<GuestConfigurationAssignmentPropertiesArgs>) {
        this.properties = value
    }

    /**
     * @param value The resource group name.
     */
    @JvmName("goiehtvyrdigapgy")
    public suspend fun resourceGroupName(`value`: Output<String>) {
        this.resourceGroupName = value
    }

    /**
     * @param value The name of the virtual machine scale set.
     */
    @JvmName("gqibtaqxtvwrceda")
    public suspend fun vmssName(`value`: Output<String>) {
        this.vmssName = value
    }

    /**
     * @param value Region where the VM is located.
     */
    @JvmName("kjybpugbwqwwvixk")
    public suspend fun location(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.location = mapped
    }

    /**
     * @param value Name of the guest configuration assignment.
     */
    @JvmName("xilfyemjcanatdro")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value Properties of the Guest configuration assignment.
     */
    @JvmName("ghxdhbtkgxhsbggc")
    public suspend fun properties(`value`: GuestConfigurationAssignmentPropertiesArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.properties = mapped
    }

    /**
     * @param argument Properties of the Guest configuration assignment.
     */
    @JvmName("kywlxxoxlqfvkewc")
    public suspend
    fun properties(argument: suspend GuestConfigurationAssignmentPropertiesArgsBuilder.() -> Unit) {
        val toBeMapped = GuestConfigurationAssignmentPropertiesArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.properties = mapped
    }

    /**
     * @param value The resource group name.
     */
    @JvmName("pwcwktkqwtrrhafr")
    public suspend fun resourceGroupName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The name of the virtual machine scale set.
     */
    @JvmName("onxtsenlbagcxesj")
    public suspend fun vmssName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.vmssName = mapped
    }

    internal fun build(): GuestConfigurationAssignmentsVMSSArgs =
        GuestConfigurationAssignmentsVMSSArgs(
            location = location,
            name = name,
            properties = properties,
            resourceGroupName = resourceGroupName,
            vmssName = vmssName,
        )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/guestconfiguration/kotlin/GuestConfigurationAssignmentsVMSSArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.guestconfiguration.kotlin

import com.pulumi.azurenative.guestconfiguration.GuestConfigurationAssignmentsVMSSArgs.builder
import com.pulumi.azurenative.guestconfiguration.kotlin.inputs.GuestConfigurationAssignmentPropertiesArgs
import com.pulumi.azurenative.guestconfiguration.kotlin.inputs.GuestConfigurationAssignmentPropertiesArgsBuilder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Guest configuration assignment is an association between a machine and guest configuration.
 * Azure REST API version: 2022-01-25.
 * ## Example Usage
 * ### Create or update guest configuration assignment
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var guestConfigurationAssignmentsVMSS = new AzureNative.GuestConfiguration.GuestConfigurationAssignmentsVMSS("guestConfigurationAssignmentsVMSS", new()
 *     {
 *         Location = "westcentralus",
 *         Name = "NotInstalledApplicationForWindows",
 *         Properties = new AzureNative.GuestConfiguration.Inputs.GuestConfigurationAssignmentPropertiesArgs
 *         {
 *             Context = "Azure policy",
 *             GuestConfiguration = new AzureNative.GuestConfiguration.Inputs.GuestConfigurationNavigationArgs
 *             {
 *                 AssignmentType = AzureNative.GuestConfiguration.AssignmentType.ApplyAndAutoCorrect,
 *                 ConfigurationParameter = new[]
 *                 {
 *                     new AzureNative.GuestConfiguration.Inputs.ConfigurationParameterArgs
 *                     {
 *                         Name = "[InstalledApplication]NotInstalledApplicationResource1;Name",
 *                         Value = "NotePad,sql",
 *                     },
 *                 },
 *                 ContentHash = "123contenthash",
 *                 ContentUri = "https://thisisfake/pacakge",
 *                 Name = "NotInstalledApplicationForWindows",
 *                 Version = "1.0.0.3",
 *             },
 *         },
 *         ResourceGroupName = "myResourceGroupName",
 *         VmssName = "myVMSSName",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/guestconfiguration/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := guestconfiguration.NewGuestConfigurationAssignmentsVMSS(ctx, "guestConfigurationAssignmentsVMSS", &guestconfiguration.GuestConfigurationAssignmentsVMSSArgs{
 * 			Location: pulumi.String("westcentralus"),
 * 			Name:     pulumi.String("NotInstalledApplicationForWindows"),
 * 			Properties: &guestconfiguration.GuestConfigurationAssignmentPropertiesArgs{
 * 				Context: pulumi.String("Azure policy"),
 * 				GuestConfiguration: &guestconfiguration.GuestConfigurationNavigationArgs{
 * 					AssignmentType: pulumi.String(guestconfiguration.AssignmentTypeApplyAndAutoCorrect),
 * 					ConfigurationParameter: guestconfiguration.ConfigurationParameterArray{
 * 						&guestconfiguration.ConfigurationParameterArgs{
 * 							Name:  pulumi.String("[InstalledApplication]NotInstalledApplicationResource1;Name"),
 * 							Value: pulumi.String("NotePad,sql"),
 * 						},
 * 					},
 * 					ContentHash: pulumi.String("123contenthash"),
 * 					ContentUri:  pulumi.String("https://thisisfake/pacakge"),
 * 					Name:        pulumi.String("NotInstalledApplicationForWindows"),
 * 					Version:     pulumi.String("1.0.0.3"),
 * 				},
 * 			},
 * 			ResourceGroupName: pulumi.String("myResourceGroupName"),
 * 			VmssName:          pulumi.String("myVMSSName"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.guestconfiguration.GuestConfigurationAssignmentsVMSS;
 * import com.pulumi.azurenative.guestconfiguration.GuestConfigurationAssignmentsVMSSArgs;
 * import com.pulumi.azurenative.guestconfiguration.inputs.GuestConfigurationAssignmentPropertiesArgs;
 * import com.pulumi.azurenative.guestconfiguration.inputs.GuestConfigurationNavigationArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var guestConfigurationAssignmentsVMSS = new GuestConfigurationAssignmentsVMSS("guestConfigurationAssignmentsVMSS", GuestConfigurationAssignmentsVMSSArgs.builder()
 *             .location("westcentralus")
 *             .name("NotInstalledApplicationForWindows")
 *             .properties(GuestConfigurationAssignmentPropertiesArgs.builder()
 *                 .context("Azure policy")
 *                 .guestConfiguration(GuestConfigurationNavigationArgs.builder()
 *                     .assignmentType("ApplyAndAutoCorrect")
 *                     .configurationParameter(ConfigurationParameterArgs.builder()
 *                         .name("[InstalledApplication]NotInstalledApplicationResource1;Name")
 *                         .value("NotePad,sql")
 *                         .build())
 *                     .contentHash("123contenthash")
 *                     .contentUri("https://thisisfake/pacakge")
 *                     .name("NotInstalledApplicationForWindows")
 *                     .version("1.0.0.3")
 *                     .build())
 *                 .build())
 *             .resourceGroupName("myResourceGroupName")
 *             .vmssName("myVMSSName")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:guestconfiguration:GuestConfigurationAssignmentsVMSS NotInstalledApplicationForWindows /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.Compute/virtualMachineScaleSets/{vmssName}/providers/Microsoft.GuestConfiguration/guestConfigurationAssignments/{name}
 * ```
 * @property location Region where the VM is located.
 * @property name Name of the guest configuration assignment.
 * @property properties Properties of the Guest configuration assignment.
 * @property resourceGroupName The resource group name.
 * @property vmssName The name of the virtual machine scale set.
 */
public data class GuestConfigurationAssignmentsVMSSArgs(
    public val location: Output<String>? = null,
    public val name: Output<String>? = null,
    public val properties: Output<GuestConfigurationAssignmentPropertiesArgs>? = null,
    public val resourceGroupName: Output<String>? = null,
    public val vmssName: Output<String>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.guestconfiguration.GuestConfigurationAssignmentsVMSSArgs> {
    override fun toJava():
        com.pulumi.azurenative.guestconfiguration.GuestConfigurationAssignmentsVMSSArgs =
        com.pulumi.azurenative.guestconfiguration.GuestConfigurationAssignmentsVMSSArgs.builder()
            .location(location?.applyValue({ args0 -> args0 }))
            .name(name?.applyValue({ args0 -> args0 }))
            .properties(properties?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .resourceGroupName(resourceGroupName?.applyValue({ args0 -> args0 }))
            .vmssName(vmssName?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [GuestConfigurationAssignmentsVMSSArgs].
 */
@PulumiTagMarker
public class GuestConfigurationAssignmentsVMSSArgsBuilder internal constructor() {
    private var location: Output<String>? = null

    private var name: Output<String>? = null

    private var properties: Output<GuestConfigurationAssignmentPropertiesArgs>? = null

    private var resourceGroupName: Output<String>? = null

    private var vmssName: Output<String>? = null

    /**
     * @param value Region where the VM is located.
     */
    @JvmName("vayyxadrwmjdhetr")
    public suspend fun location(`value`: Output<String>) {
        this.location = value
    }

    /**
     * @param value Name of the guest configuration assignment.
     */
    @JvmName("syuxhredcugcjcfu")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value Properties of the Guest configuration assignment.
     */
    @JvmName("tkoggnflwmbtynfc")
    public suspend fun properties(`value`: Output<GuestConfigurationAssignmentPropertiesArgs>) {
        this.properties = value
    }

    /**
     * @param value The resource group name.
     */
    @JvmName("schpfxttassnnmyy")
    public suspend fun resourceGroupName(`value`: Output<String>) {
        this.resourceGroupName = value
    }

    /**
     * @param value The name of the virtual machine scale set.
     */
    @JvmName("lcvgbxlnxidshghv")
    public suspend fun vmssName(`value`: Output<String>) {
        this.vmssName = value
    }

    /**
     * @param value Region where the VM is located.
     */
    @JvmName("poqyvbnwvjlmlqft")
    public suspend fun location(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.location = mapped
    }

    /**
     * @param value Name of the guest configuration assignment.
     */
    @JvmName("sraqfpwmyuefummw")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value Properties of the Guest configuration assignment.
     */
    @JvmName("aqigyhuwbmaqhsjy")
    public suspend fun properties(`value`: GuestConfigurationAssignmentPropertiesArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.properties = mapped
    }

    /**
     * @param argument Properties of the Guest configuration assignment.
     */
    @JvmName("aybdfqugepiagctf")
    public suspend
    fun properties(argument: suspend GuestConfigurationAssignmentPropertiesArgsBuilder.() -> Unit) {
        val toBeMapped = GuestConfigurationAssignmentPropertiesArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.properties = mapped
    }

    /**
     * @param value The resource group name.
     */
    @JvmName("mhbftgtdqgxowkhc")
    public suspend fun resourceGroupName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The name of the virtual machine scale set.
     */
    @JvmName("nowalrxllrhnqqol")
    public suspend fun vmssName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.vmssName = mapped
    }

    internal fun build(): GuestConfigurationAssignmentsVMSSArgs =
        GuestConfigurationAssignmentsVMSSArgs(
            location = location,
            name = name,
            properties = properties,
            resourceGroupName = resourceGroupName,
            vmssName = vmssName,
        )
}
